@@ -14,6 +14,7 @@ from .utils import get_ip_address
 log = logging.getLogger(__name__)
 
 NS = "{urn:schemas-upnp-org:event-1-0}"
+SUCCESS = '<html><body><h1>200 OK</h1></body></html>'
 
 
 class SubscriptionRegistry(object):
@@ -48,12 +49,16 @@ class SubscriptionRegistry(object):
 
     def _handle(self, environ, start_response):
         device = self._devices[environ['REMOTE_ADDR']]
-        start_response('200 OK', [('Content-Type', 'text/html')])
         doc = cElementTree.parse(environ['wsgi.input'])
         for propnode in doc.findall('./{0}property'.format(NS)):
             for property_ in propnode.getchildren():
                 self._event(device, property_.tag, property_.text)
-        yield '<html><body><h1>200 OK</h1></body></html>'
+        start_response('200 OK', [
+            ('Content-Type', 'text/html'), 
+            ('Content-Length', len(SUCCESS)),
+            ('Connection', 'close')
+        ])
+        yield SUCCESS
 
     def _event(self, device, type_, value):
         for t, callback in self._callbacks.get(device, ()):
